@@ -150,7 +150,6 @@ class Exceptions:
     InvalidBucketNameFilterException: Type[BotocoreClientError]
     InvalidComputePlatformException: Type[BotocoreClientError]
     InvalidDeployedStateFilterException: Type[BotocoreClientError]
-    InvalidDeploymentConfigIdException: Type[BotocoreClientError]
     InvalidDeploymentConfigNameException: Type[BotocoreClientError]
     InvalidDeploymentGroupNameException: Type[BotocoreClientError]
     InvalidDeploymentIdException: Type[BotocoreClientError]
@@ -217,7 +216,7 @@ class Exceptions:
 
 class CodeDeployClient:
     """
-    [CodeDeploy.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client)
+    [CodeDeploy.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client)
     """
 
     meta: ClientMeta
@@ -227,59 +226,59 @@ class CodeDeployClient:
         self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
-        [Client.add_tags_to_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
+        [Client.add_tags_to_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
         """
 
     def batch_get_application_revisions(
         self, applicationName: str, revisions: List["RevisionLocationTypeDef"]
     ) -> BatchGetApplicationRevisionsOutputTypeDef:
         """
-        [Client.batch_get_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
+        [Client.batch_get_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
         """
 
     def batch_get_applications(
         self, applicationNames: List[str]
     ) -> BatchGetApplicationsOutputTypeDef:
         """
-        [Client.batch_get_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
+        [Client.batch_get_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
         """
 
     def batch_get_deployment_groups(
         self, applicationName: str, deploymentGroupNames: List[str]
     ) -> BatchGetDeploymentGroupsOutputTypeDef:
         """
-        [Client.batch_get_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
+        [Client.batch_get_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
         """
 
     def batch_get_deployment_instances(
         self, deploymentId: str, instanceIds: List[str]
     ) -> BatchGetDeploymentInstancesOutputTypeDef:
         """
-        [Client.batch_get_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
+        [Client.batch_get_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
         """
 
     def batch_get_deployment_targets(
         self, deploymentId: str = None, targetIds: List[str] = None
     ) -> BatchGetDeploymentTargetsOutputTypeDef:
         """
-        [Client.batch_get_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
+        [Client.batch_get_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
         """
 
     def batch_get_deployments(self, deploymentIds: List[str]) -> BatchGetDeploymentsOutputTypeDef:
         """
-        [Client.batch_get_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
+        [Client.batch_get_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
         """
 
     def batch_get_on_premises_instances(
         self, instanceNames: List[str]
     ) -> BatchGetOnPremisesInstancesOutputTypeDef:
         """
-        [Client.batch_get_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
+        [Client.batch_get_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
         """
 
     def continue_deployment(
@@ -288,7 +287,7 @@ class CodeDeployClient:
         deploymentWaitType: Literal["READY_WAIT", "TERMINATION_WAIT"] = None,
     ) -> None:
         """
-        [Client.continue_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
+        [Client.continue_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
         """
 
     def create_application(
@@ -298,7 +297,7 @@ class CodeDeployClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationOutputTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
         """
 
     def create_deployment(
@@ -315,7 +314,7 @@ class CodeDeployClient:
         fileExistsBehavior: Literal["DISALLOW", "OVERWRITE", "RETAIN"] = None,
     ) -> CreateDeploymentOutputTypeDef:
         """
-        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
+        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
         """
 
     def create_deployment_config(
@@ -326,7 +325,7 @@ class CodeDeployClient:
         computePlatform: Literal["Server", "Lambda", "ECS"] = None,
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
-        [Client.create_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
+        [Client.create_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
         """
 
     def create_deployment_group(
@@ -341,6 +340,7 @@ class CodeDeployClient:
         triggerConfigurations: List["TriggerConfigTypeDef"] = None,
         alarmConfiguration: "AlarmConfigurationTypeDef" = None,
         autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
+        outdatedInstancesStrategy: Literal["UPDATE", "IGNORE"] = None,
         deploymentStyle: "DeploymentStyleTypeDef" = None,
         blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
         loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
@@ -350,41 +350,41 @@ class CodeDeployClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateDeploymentGroupOutputTypeDef:
         """
-        [Client.create_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
+        [Client.create_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
         """
 
     def delete_application(self, applicationName: str) -> None:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
         """
 
     def delete_deployment_config(self, deploymentConfigName: str) -> None:
         """
-        [Client.delete_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
+        [Client.delete_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
         """
 
     def delete_deployment_group(
         self, applicationName: str, deploymentGroupName: str
     ) -> DeleteDeploymentGroupOutputTypeDef:
         """
-        [Client.delete_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
+        [Client.delete_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
         """
 
     def delete_git_hub_account_token(
         self, tokenName: str = None
     ) -> DeleteGitHubAccountTokenOutputTypeDef:
         """
-        [Client.delete_git_hub_account_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
+        [Client.delete_git_hub_account_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
         """
 
     def delete_resources_by_external_id(self, externalId: str = None) -> Dict[str, Any]:
         """
-        [Client.delete_resources_by_external_id documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.delete_resources_by_external_id)
+        [Client.delete_resources_by_external_id documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.delete_resources_by_external_id)
         """
 
     def deregister_on_premises_instance(self, instanceName: str) -> None:
         """
-        [Client.deregister_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
+        [Client.deregister_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
         """
 
     def generate_presigned_url(
@@ -395,55 +395,55 @@ class CodeDeployClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
         """
 
     def get_application(self, applicationName: str) -> GetApplicationOutputTypeDef:
         """
-        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
+        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
         """
 
     def get_application_revision(
         self, applicationName: str, revision: "RevisionLocationTypeDef"
     ) -> GetApplicationRevisionOutputTypeDef:
         """
-        [Client.get_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
+        [Client.get_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
         """
 
     def get_deployment(self, deploymentId: str) -> GetDeploymentOutputTypeDef:
         """
-        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
+        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
         """
 
     def get_deployment_config(self, deploymentConfigName: str) -> GetDeploymentConfigOutputTypeDef:
         """
-        [Client.get_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
+        [Client.get_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
         """
 
     def get_deployment_group(
         self, applicationName: str, deploymentGroupName: str
     ) -> GetDeploymentGroupOutputTypeDef:
         """
-        [Client.get_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
+        [Client.get_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
         """
 
     def get_deployment_instance(
         self, deploymentId: str, instanceId: str
     ) -> GetDeploymentInstanceOutputTypeDef:
         """
-        [Client.get_deployment_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
+        [Client.get_deployment_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
         """
 
     def get_deployment_target(
         self, deploymentId: str = None, targetId: str = None
     ) -> GetDeploymentTargetOutputTypeDef:
         """
-        [Client.get_deployment_target documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
+        [Client.get_deployment_target documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
         """
 
     def get_on_premises_instance(self, instanceName: str) -> GetOnPremisesInstanceOutputTypeDef:
         """
-        [Client.get_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
+        [Client.get_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
         """
 
     def list_application_revisions(
@@ -457,24 +457,24 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListApplicationRevisionsOutputTypeDef:
         """
-        [Client.list_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
+        [Client.list_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
         """
 
     def list_applications(self, nextToken: str = None) -> ListApplicationsOutputTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
         """
 
     def list_deployment_configs(self, nextToken: str = None) -> ListDeploymentConfigsOutputTypeDef:
         """
-        [Client.list_deployment_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
+        [Client.list_deployment_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
         """
 
     def list_deployment_groups(
         self, applicationName: str, nextToken: str = None
     ) -> ListDeploymentGroupsOutputTypeDef:
         """
-        [Client.list_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
+        [Client.list_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
         """
 
     def list_deployment_instances(
@@ -487,7 +487,7 @@ class CodeDeployClient:
         instanceTypeFilter: List[Literal["Blue", "Green"]] = None,
     ) -> ListDeploymentInstancesOutputTypeDef:
         """
-        [Client.list_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
+        [Client.list_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
         """
 
     def list_deployment_targets(
@@ -497,7 +497,7 @@ class CodeDeployClient:
         targetFilters: Dict[Literal["TargetStatus", "ServerInstanceLabel"], List[str]] = None,
     ) -> ListDeploymentTargetsOutputTypeDef:
         """
-        [Client.list_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
+        [Client.list_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
         """
 
     def list_deployments(
@@ -521,14 +521,14 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListDeploymentsOutputTypeDef:
         """
-        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
+        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
         """
 
     def list_git_hub_account_token_names(
         self, nextToken: str = None
     ) -> ListGitHubAccountTokenNamesOutputTypeDef:
         """
-        [Client.list_git_hub_account_token_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
+        [Client.list_git_hub_account_token_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
         """
 
     def list_on_premises_instances(
@@ -538,14 +538,14 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListOnPremisesInstancesOutputTypeDef:
         """
-        [Client.list_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
+        [Client.list_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
         """
 
     def list_tags_for_resource(
         self, ResourceArn: str, NextToken: str = None
     ) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
         """
 
     def put_lifecycle_event_hook_execution_status(
@@ -557,57 +557,57 @@ class CodeDeployClient:
         ] = None,
     ) -> PutLifecycleEventHookExecutionStatusOutputTypeDef:
         """
-        [Client.put_lifecycle_event_hook_execution_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
+        [Client.put_lifecycle_event_hook_execution_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
         """
 
     def register_application_revision(
         self, applicationName: str, revision: "RevisionLocationTypeDef", description: str = None
     ) -> None:
         """
-        [Client.register_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
+        [Client.register_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
         """
 
     def register_on_premises_instance(
         self, instanceName: str, iamSessionArn: str = None, iamUserArn: str = None
     ) -> None:
         """
-        [Client.register_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
+        [Client.register_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
         """
 
     def remove_tags_from_on_premises_instances(
         self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
-        [Client.remove_tags_from_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
+        [Client.remove_tags_from_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
         """
 
     def skip_wait_time_for_instance_termination(self, deploymentId: str = None) -> None:
         """
-        [Client.skip_wait_time_for_instance_termination documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
+        [Client.skip_wait_time_for_instance_termination documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
         """
 
     def stop_deployment(
         self, deploymentId: str, autoRollbackEnabled: bool = None
     ) -> StopDeploymentOutputTypeDef:
         """
-        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
+        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
         """
 
     def update_application(
         self, applicationName: str = None, newApplicationName: str = None
     ) -> None:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
         """
 
     def update_deployment_group(
@@ -623,6 +623,7 @@ class CodeDeployClient:
         triggerConfigurations: List["TriggerConfigTypeDef"] = None,
         alarmConfiguration: "AlarmConfigurationTypeDef" = None,
         autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
+        outdatedInstancesStrategy: Literal["UPDATE", "IGNORE"] = None,
         deploymentStyle: "DeploymentStyleTypeDef" = None,
         blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
         loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
@@ -631,7 +632,7 @@ class CodeDeployClient:
         onPremisesTagSet: "OnPremisesTagSetTypeDef" = None,
     ) -> UpdateDeploymentGroupOutputTypeDef:
         """
-        [Client.update_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
+        [Client.update_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
         """
 
     @overload
@@ -639,7 +640,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_application_revisions"]
     ) -> ListApplicationRevisionsPaginator:
         """
-        [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
+        [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
         """
 
     @overload
@@ -647,7 +648,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
+        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
         """
 
     @overload
@@ -655,7 +656,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_configs"]
     ) -> ListDeploymentConfigsPaginator:
         """
-        [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
+        [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
         """
 
     @overload
@@ -663,7 +664,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_groups"]
     ) -> ListDeploymentGroupsPaginator:
         """
-        [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
+        [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
         """
 
     @overload
@@ -671,7 +672,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_instances"]
     ) -> ListDeploymentInstancesPaginator:
         """
-        [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
+        [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
         """
 
     @overload
@@ -679,7 +680,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_targets"]
     ) -> ListDeploymentTargetsPaginator:
         """
-        [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
+        [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
         """
 
     @overload
@@ -687,7 +688,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployments"]
     ) -> ListDeploymentsPaginator:
         """
-        [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
+        [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
         """
 
     @overload
@@ -695,7 +696,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_git_hub_account_token_names"]
     ) -> ListGitHubAccountTokenNamesPaginator:
         """
-        [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
+        [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
         """
 
     @overload
@@ -703,12 +704,12 @@ class CodeDeployClient:
         self, operation_name: Literal["list_on_premises_instances"]
     ) -> ListOnPremisesInstancesPaginator:
         """
-        [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
+        [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
         """
 
     def get_waiter(
         self, waiter_name: Literal["deployment_successful"]
     ) -> DeploymentSuccessfulWaiter:
         """
-        [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
+        [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
         """
